summaryrefslogtreecommitdiff
path: root/drivers/gpu/drm/xe/xe_guc_ct_types.h
diff options
context:
space:
mode:
authorRodrigo Vivi <rodrigo.vivi@intel.com>2023-05-16 17:54:08 +0300
committerRodrigo Vivi <rodrigo.vivi@intel.com>2023-12-20 02:33:52 +0300
commita7ca8157ec7b59b597ba47cb98eaa82cb0b1d4af (patch)
treec788657d06ebb36f1b1e1d8796763f6fb59dc710 /drivers/gpu/drm/xe/xe_guc_ct_types.h
parent656d29506ca89b4af1d2380ff4cab15f40ae9e19 (diff)
downloadlinux-a7ca8157ec7b59b597ba47cb98eaa82cb0b1d4af.tar.xz
drm/xe: Extract non mapped regions out of GuC CTB into its own struct.
No functional change here. The goal is to have a clear split between the mapped portions of the CTB and the static information, so we can easily capture snapshots that will be used for later read out with the devcoredump infrastructure. Signed-off-by: Rodrigo Vivi <rodrigo.vivi@intel.com> Reviewed-by: Matthew Brost <matthew.brost@intel.com>
Diffstat (limited to 'drivers/gpu/drm/xe/xe_guc_ct_types.h')
-rw-r--r--drivers/gpu/drm/xe/xe_guc_ct_types.h20
1 files changed, 14 insertions, 6 deletions
diff --git a/drivers/gpu/drm/xe/xe_guc_ct_types.h b/drivers/gpu/drm/xe/xe_guc_ct_types.h
index fd27dacf00c5..64e3dd14d4b2 100644
--- a/drivers/gpu/drm/xe/xe_guc_ct_types.h
+++ b/drivers/gpu/drm/xe/xe_guc_ct_types.h
@@ -19,13 +19,9 @@
struct xe_bo;
/**
* struct guc_ctb - GuC command transport buffer (CTB)
*/
-struct guc_ctb {
- /** @desc: dma buffer map for CTB descriptor */
- struct iosys_map desc;
- /** @cmds: dma buffer map for CTB commands */
- struct iosys_map cmds;
+struct guc_ctb_info {
/** @size: size of CTB commands (DW) */
u32 size;
/** @resv_space: reserved space of CTB commands (DW) */
@@ -41,6 +37,18 @@ struct guc_ctb {
};
/**
+ * struct guc_ctb - GuC command transport buffer (CTB)
+ */
+struct guc_ctb {
+ /** @desc: dma buffer map for CTB descriptor */
+ struct iosys_map desc;
+ /** @cmds: dma buffer map for CTB commands */
+ struct iosys_map cmds;
+ /** @info: CTB info */
+ struct guc_ctb_info info;
+};
+
+/**
* struct xe_guc_ct - GuC command transport (CT) layer
*
* Includes a pair of CT buffers for bi-directional communication and tracking
@@ -19,13 +19,9 @@
struct xe_bo;
/**
- * struct guc_ctb - GuC command transport buffer (CTB)
+ * struct guc_ctb_info - GuC command transport buffer (CTB) info
*/